#include <Adafruit_NeoPixel.h>

// constants won't change. They're used here to set pin numbers:
#define buttonPin  14    // the number of the pushbutton pin
#define PIXEL_PIN    12    // Digital IO pin connected to the NeoPixels.
#define PIXEL_COUNT 16

// Parameter 1 = number of pixels in strip,  neopixel stick has 8
// Parameter 2 = pin number (most are valid)
// Parameter 3 = pixel type flags, add together as needed:
//   NEO_RGB     Pixels are wired for RGB bitstream
//   NEO_GRB     Pixels are wired for GRB bitstream, correct for neopixel stick
//   NEO_KHZ400  400 KHz bitstream (e.g. FLORA pixels)
//   NEO_KHZ800  800 KHz bitstream (e.g. High Density LED strip), correct for neopixel stick
Adafruit_NeoPixel strip = Adafruit_NeoPixel(PIXEL_COUNT, PIXEL_PIN, NEO_GRB + NEO_KHZ800);

// Variables will change:
int ledState = HIGH;         // the current state of the output pin
int buttonState;             // the current reading from the input pin
int lastButtonState = LOW;   // the previous reading from the input pin
int showType = 0;

// the following variables are unsigned longs because the time, measured in
// milliseconds, will quickly become a bigger number than can be stored in an int.
unsigned long lastDebounceTime = 0;  // the last time the output pin was toggled
unsigned long debounceDelay = 90;    // the debounce time; increase if the output flickers

void setup() {
  pinMode(buttonPin, INPUT);
Serial.begin(9600);
strip.begin();
  strip.show(); // Initialize all pixels to 'off'
}

void loop() {
  // read the state of the switch into a local variable:
  int reading = digitalRead(buttonPin);
  Serial.print("reading: ");
  Serial.println(reading);
  // check to see if you just pressed the button
  // (i.e. the input went from LOW to HIGH), and you've waited long enough
  // since the last press to ignore any noise:

  // If the switch changed, due to noise or pressing:
  if (reading != lastButtonState) {
    // reset the debouncing timer
    lastDebounceTime = millis();
    Serial.print("lastDebounceTime: ");
    Serial.println(lastDebounceTime);
  }

  if ((millis() - lastDebounceTime) > debounceDelay) {
    // whatever the reading is at, it's been there for longer than the debounce
    // delay, so take it as the actual current state:

    // if the button state has changed:
    if (reading != buttonState) {
      buttonState = reading;
      Serial.print("buttonState: ");
      Serial.println(buttonState);
      // only toggle the LED if the new button state is HIGH
      if (buttonState == HIGH) {
        showType++;
        if (showType > 9){
        showType=0;
        }
        Serial.print("showType: ");
        Serial.println(showType);
        startShow(showType);
      }
    }
  }

  // save the reading. Next time through the loop, it'll be the lastButtonState:
  lastButtonState = reading;
  Serial.print("lastButtonState: ");
  Serial.println(lastButtonState);
}

// Fill the dots one after the other with a color
void colorWipe(uint32_t c, uint8_t wait) {
  for(uint16_t i=0; i<strip.numPixels(); i++) {
    strip.setPixelColor(i, c);
    strip.show();
    delay(wait);
  }
}

void startShow(int i) {
switch(i){
    case 0: colorWipe(strip.Color(0, 0, 0), 50);    // Black/off
            break;
    case 1: colorWipe(strip.Color(255, 0, 0), 50);  // Red
            break;
    case 2: colorWipe(strip.Color(0, 255, 0), 50);  // Green
            break;
    case 3: colorWipe(strip.Color(0, 0, 255), 50);  // Blue
            break;
    case 4: colorWipe(strip.Color(0, random(255), 255), 50);
            break;
    case 5: colorWipe(strip.Color(random(255), random(255), 0), 50);
            break;
    case 6: colorWipe(strip.Color(0, 0, random(255)), 50);
            break;
    case 7: colorWipe(strip.Color(random(255), random(255), 255), 50);
            break;
    case 8: colorWipe(strip.Color(0, random(255), 255), 50);
            break;
    case 9: colorWipe(strip.Color(random(255), 0, random(255)), 50);
            break;
      }
}
